Pyramid
=======

.. image:: https://travis-ci.org/Pylons/pyramid.png?branch=1.7-branch
        :target: https://travis-ci.org/Pylons/pyramid
        :alt: 1.7-branch Travis CI Status

.. image:: https://readthedocs.org/projects/pyramid/badge/?version=master
        :target: http://docs.pylonsproject.org/projects/pyramid/en/master/
        :alt: Master Documentation Status

.. image:: https://readthedocs.org/projects/pyramid/badge/?version=latest
        :target: http://docs.pylonsproject.org/projects/pyramid/en/latest/
        :alt: Latest Documentation Status

.. image:: https://img.shields.io/badge/irc-freenode-blue.svg
        :target: https://webchat.freenode.net/?channels=pyramid
        :alt: IRC Freenode

Pyramid is a small, fast, down-to-earth, open source Python web framework. It
makes real-world web application development and deployment more fun, more
predictable, and more productive.

Pyramid is produced by the `Pylons Project <http://pylonsproject.org/>`_.

Support and Documentation
-------------------------

See the `Pylons Project website <http://pylonsproject.org/>`_ to view
documentation, report bugs, and obtain support.

Developing and Contributing
---------------------------

See ``HACKING.txt`` and ``contributing.md`` for guidelines for running tests,
adding features, coding style, and updating documentation when developing in or
contributing to Pyramid.

License
-------

Pyramid is offered under the BSD-derived `Repoze Public License
<http://repoze.org/license.html>`_.

Authors
-------

Pyramid is made available by `Agendaless Consulting <http://agendaless.com>`_
and a team of contributors.

